---
title: <span class="badge object-type-scalar"></span> KibibytesPerSecond
---
# <span class="badge object-type-scalar"></span> KibibytesPerSecond

Data rate: kibibytes/sec

## Definition

```python
# Data rate: kibibytes/sec
KibibytesPerSecond: typing.Literal["KiBs"] = "KiBs"
```
